@@ -15,15 +15,6 @@ QMainWindow(parent, Qt::FramelessWindowHint),
     ui->switchButton->setAttribute(Qt::WA_TranslucentBackground);
     palette.setColor(QPalette::Base, Qt::transparent);
     ui->centralWidget->setPalette(palette);
-    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, 50%); \
-     border-style: outset; \
-     border-width: 0px; \
-     border-radius: 10px; \
-     border-color: rgba(0, 0, 0, 50%); \
-     font: bold 14px; \
-     min-width: 48px; \
-     width: 48px; \
-     padding: 6px;");
     QSettings settings;
     if (!settings.contains("profilechangerwidget/width"))
         settings.setValue("profilechangerwidget/width", 96);
@@ -122,6 +113,16 @@ void ProfileChangerWidget::reloadSettings()
     this->setGeometry(this->x(), this->y(),
                       settings.value("profilechangerwidget/width").toInt(),
                       settings.value("profilechangerwidget/height").toInt());
+    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, 70%); \
+     border-style: outset; \
+     border-width: 0px; \
+     border-radius: 10px; \
+     border-color: rgba(0, 0, 0, 70%); \
+     font: bold 14px; \
+     min-width: 48px; \
+     width: " + settings.value("profilechangerwidget/width").toString() +  "px; \
+     height: " + settings.value("profilechangerwidget/height").toString() +  "px; \
+     padding: 6px;");
     this->refreshIcon();
 }
 
