@@ -29,11 +29,6 @@ void SettingsDialog::accept()
         QMaemo5InformationBox::information(this, tr("Fields cannot be empty!"));
         return;
     }
-    if (ui->heightBox->text() == "99") {
-        QMaemo5InformationBox::information(this, "TranslationPath: " + QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-        return;
-    }
-
 
     settings.setValue("profilechangerwidget/width", ui->widthBox->value());
     settings.setValue("profilechangerwidget/height", ui->heightBox->value());
